==> trending_topics-1.0.1.tar.gz: trending_topics/src/Plugin/Block/TrendingTopicsListBlock.php <==
<?php

namespace Drupal\trending_topics\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'Trending Topics List' block.
 *
 * @Block(
 *   id = "trending_topics_list_block",
 *   admin_label = @Translation("Trending Topics"),
 * )
 */
class TrendingTopicsListBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The trending topics.
   *
   * @var Drupal\trending_topics\Services\TrendingTopicsService
   */
  protected $trendingTopics;

  /**
   * Constructs an EventCountdownBlock object.
   *
   * @param array $configuration
   *   The block configuration.
   * @param string $plugin_id
   *   The ID of the plugin.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param mixed $trendingTopics
   *   The trending topics.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    $trendingTopics) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->trendingTopics = $trendingTopics;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container,
  array $configuration,
  $plugin_id,
  $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('trending_topics')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $trending_topics = $this->trendingTopics->getTrendingTopics();
    $message = [
      '#type' => 'markup',
      '#markup' => $trending_topics,
      '#cache' => [
        'max-age' => 0,
      ],
    ];
    return $message;
  }

}

==> trending_topics-1.0.3.tar.gz: trending_topics/src/Plugin/Block/TrendingTopicsListBlock.php <==
<?php

namespace Drupal\trending_topics\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'Trending Topics List' block.
 *
 * @Block(
 *   id = "trending_topics_list_block",
 *   admin_label = @Translation("Trending Topics"),
 * )
 */
class TrendingTopicsListBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The trending topics.
   *
   * @var \Drupal\trending_topics\Services\TrendingTopicsService
   */
  protected $trendingTopics;

  /**
   * Constructs an EventCountdownBlock object.
   *
   * @param array $configuration
   *   The block configuration.
   * @param string $plugin_id
   *   The ID of the plugin.
   * @param mixed $plugin_definition
   *   The plugin definition.
   * @param mixed $trendingTopics
   *   The trending topics.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    $trendingTopics) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->trendingTopics = $trendingTopics;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container,
  array $configuration,
  $plugin_id,
  $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('trending_topics')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $trending_topics = $this->trendingTopics->getTrendingTopics();
    return $message = [
      '#type' => 'markup',
      '#markup' => $trending_topics,
      '#cache' => [
        'tags' => 'node_list',
      ],
    ];
  }

}
